@@ -44,7 +44,6 @@ class TVarFigureSpec(pg.GraphicsLayout):
             self.xaxis.enableAutoSIPrefix(enable=False)
         # Set up the y axis
         self.yaxis = AxisItem('left')
-        self.yaxis.setWidth(100)
         self.yaxis.setStyle(textFillLimits=pytplot.tplot_opt_glob["axis_tick_num"])  # Set an absurdly high number for the first 3, ensuring that at least 3 axis labels are always present
         # Creating axes to bound the plots with lines
         self.xaxis2 = DateAxis(orientation='top', showValues=False)
@@ -59,6 +58,9 @@ class TVarFigureSpec(pg.GraphicsLayout):
                                                                 'right': self.yaxis2,
                                                                 'top': self.xaxis2}, viewBox=vb)
 
+        # Turn off zooming in on the y-axis, time resolution is much more important
+        self.plotwindow.setMouseEnabled(y=pytplot.tplot_opt_glob['y_axis_zoom'])
+
         if pytplot.data_quants[self.tvar_name].attrs['plot_options']['extras']['border']:
             self.plotwindow.showAxis("top")
             self.plotwindow.showAxis("right")
